#!/usr/bin/env bash

version=
gitArgs=

while [ "$#" -gt 0 ]; do
	i="$1"
	shift 1
	case "$i" in
	--version|-v)
		version="$1"
		shift 1
		;;
	--git-args)
	  gitArgs="$gitArgs $1"
	  shift 1
	  ;;
	*)
		echo "$0: unknown option \`$i'"
		exit 1
		;;
	esac
done

# Create a working environment
CWD=$(pwd)

TMP=$(mktemp -d)
cd "$TMP"

# Fetch the latest source or the required version
gitUrl="https://github.com/demarches-simplifiees/demarches-simplifiees.fr.git"

if [ -n "$version" ]; then
	git clone --depth 1 --branch $version $gitUrl .
else
	git clone --depth 1 $gitUrl .
fi

# Generate gemset.nix
nix-shell -p bundix --run "bundix -l"

# Copy the new files
cp gemset.nix Gemfile Gemfile.lock "$CWD/rubyEnv/"

# Print the new source details
nix-shell -p nurl --run "nurl $gitUrl $version"
